<?php
/**
 * Created by PhpStorm.
 * User: Noa
 * Date: 09/10/2017
 * Time: 15:38
 */

use GuzzleHttp\Psr7\Request;
use GuzzleHttp\Psr7\Response;

/**
 * Append a X-RMN-Lab-Response header to response if X-RMN-Lab header is present
 * beside this header request value must follow the pattern "rmn_request_\d+"
 * otherwise a 400 error code with a json body with a message "Missing or invalid
 * @param Request $request
 * @return Response
 */
function addHeaderMiddleware(Request $request) {

    /**
     * @var Response $response
     */
    $response = new Response();

    $rmnHeader = $request->getHeader('X-RMN-Lab');

    if (!count($rmnHeader)) {

        $message = json_encode([
            "code" => 1,
            "message" => 'Missing "X-RMN-Lab" header'
        ]);

        $response = $response->withStatus(400);
        $response = $response->withHeader('Content-Type', 'application/json');
        $response->getBody()->write($message);
        return $response;
    }

    preg_match('#rmn_request_(\d+)#', $rmnHeader[0], $matchesRequest);

    if (!count($matchesRequest)) {

        $message = json_encode([
            "code" => 2,
            "message" => 'Invalid "X-RMN-Lab" header: '.$rmnHeader[0]
        ]);

        $response = $response->withStatus(400);
        $response = $response->withHeader('Content-Type', 'application/json');
        $response->getBody()->write($message);
        return $response;
    }


    $response = $response->withHeader('X-RMN-Lab-Response', 'rmn_response_'.$matchesRequest[1]);

    return $response;
}